@@ -89,7 +89,10 @@ brasero_medium_selection_buildable_init (GtkBuildableIface *iface)
 	parent_buildable_iface = g_type_interface_peek_parent (iface);
 } 
 
-G_DEFINE_TYPE_WITH_CODE (BraseroMediumSelection, brasero_medium_selection, GTK_TYPE_COMBO_BOX, G_IMPLEMENT_INTERFACE (GTK_TYPE_BUILDABLE, brasero_medium_selection_buildable_init));
+G_DEFINE_TYPE_WITH_CODE (BraseroMediumSelection,
+                         brasero_medium_selection,
+                         GTK_TYPE_COMBO_BOX,
+                         G_IMPLEMENT_INTERFACE (GTK_TYPE_BUILDABLE, brasero_medium_selection_buildable_init));
 
 void
 brasero_medium_selection_foreach (BraseroMediumSelection *selection,
@@ -196,12 +199,9 @@ brasero_medium_selection_update_used_space (BraseroMediumSelection *selector,
 					    BraseroMedium *medium_arg,
 					    guint used_space)
 {
-	BraseroMediumSelectionPrivate *priv;
 	GtkTreeModel *model;
 	GtkTreeIter iter;
 
-	priv = BRASERO_MEDIUM_SELECTION_PRIVATE (selector);
-
 	model = gtk_combo_box_get_model (GTK_COMBO_BOX (selector));
 	if (!gtk_tree_model_get_iter_first (model, &iter))
 		return;
@@ -233,9 +233,6 @@ static void
 brasero_medium_selection_set_show_used_space (BraseroMediumSelection *selector)
 {
 	GtkCellRenderer *renderer;
-	BraseroMediumSelectionPrivate *priv;
-
-	priv = BRASERO_MEDIUM_SELECTION_PRIVATE (selector);
 
 	gtk_cell_layout_clear (GTK_CELL_LAYOUT (selector));
 
@@ -269,9 +266,7 @@ brasero_medium_selection_update_media_string (BraseroMediumSelection *self)
 {
 	GtkTreeModel *model;
 	GtkTreeIter iter;
-	gboolean valid;
 
-	valid = FALSE;
 	model = gtk_combo_box_get_model (GTK_COMBO_BOX (self));
 	if (!gtk_tree_model_get_iter_first (model, &iter))
 		return;
@@ -338,12 +333,9 @@ brasero_medium_selection_set_current_medium (BraseroMediumSelection *self,
 static void
 brasero_drive_selection_set_tooltip (BraseroMediumSelection *self)
 {
-	BraseroMediumSelectionPrivate *priv;
 	BraseroMedium *medium;
 	gchar *tooltip;
 
-	priv = BRASERO_MEDIUM_SELECTION_PRIVATE (self);
-
 	medium = brasero_medium_selection_get_active (self);
 	if (medium) {
 		tooltip = brasero_medium_get_tooltip (medium);
@@ -359,10 +351,8 @@ brasero_drive_selection_set_tooltip (BraseroMediumSelection *self)
 static void
 brasero_medium_selection_changed (GtkComboBox *combo)
 {
-	GtkTreeModel *model;
 	GtkTreeIter iter;
 
-	model = gtk_combo_box_get_model (combo);
 	if (!gtk_combo_box_get_active_iter (combo, &iter))
 		return;
 
@@ -392,7 +382,6 @@ brasero_medium_selection_set_active (BraseroMediumSelection *selector,
 	g_return_val_if_fail (BRASERO_IS_MEDIUM_SELECTION (selector), FALSE);
 
 	priv = BRASERO_MEDIUM_SELECTION_PRIVATE (selector);
-
 	if (priv->active == medium)
 		return TRUE;
 
@@ -436,7 +425,7 @@ BraseroMedium *
 brasero_medium_selection_get_active (BraseroMediumSelection *selector)
 {
 	BraseroMediumSelectionPrivate *priv;
-
+	
 	g_return_val_if_fail (selector != NULL, NULL);
 	g_return_val_if_fail (BRASERO_IS_MEDIUM_SELECTION (selector), NULL);
 
@@ -487,9 +476,6 @@ brasero_medium_selection_add_no_disc_entry (BraseroMediumSelection *self)
 {
 	GtkTreeIter iter;
 	GtkTreeModel *model;
-	BraseroMediumSelectionPrivate *priv;
-
-	priv = BRASERO_MEDIUM_SELECTION_PRIVATE (self);
 
 	/* Nothing's available. Say it. Two cases here, either we're
 	 * still probing drives or there isn't actually any available
@@ -832,6 +818,12 @@ brasero_medium_selection_medium_removed_cb (BraseroMediumMonitor *monitor,
 	}
 }
 
+static void
+brasero_medium_selection_constructed (GObject *object)
+{
+	brasero_medium_selection_set_show_used_space (object);
+}
+
 static void
 brasero_medium_selection_init (BraseroMediumSelection *object)
 {
@@ -863,8 +855,6 @@ brasero_medium_selection_init (BraseroMediumSelection *object)
 
 	gtk_combo_box_set_model (GTK_COMBO_BOX (object), GTK_TREE_MODEL (model));
 	g_object_unref (model);
-
-	brasero_medium_selection_set_show_used_space (object);
 }
 
 static void
@@ -893,12 +883,8 @@ brasero_medium_selection_set_property (GObject *object,
 				       const GValue *value,
 				       GParamSpec *pspec)
 {
-	BraseroMediumSelectionPrivate *priv;
-
 	g_return_if_fail (BRASERO_IS_MEDIUM_SELECTION (object));
 
-	priv = BRASERO_MEDIUM_SELECTION_PRIVATE (object);
-
 	switch (prop_id)
 	{
 	case PROP_MEDIA_TYPE:
@@ -949,6 +935,7 @@ brasero_medium_selection_class_init (BraseroMediumSelectionClass *klass)
 
 	g_type_class_add_private (klass, sizeof (BraseroMediumSelectionPrivate));
 
+	object_class->constructed = brasero_medium_selection_constructed;
 	object_class->finalize = brasero_medium_selection_finalize;
 	object_class->set_property = brasero_medium_selection_set_property;
 	object_class->get_property = brasero_medium_selection_get_property;
